==> dhp-schemas-5.17.4-20240308.005042-34-sources.jar: eu/dnetlib/dhp/schema/oaf/OafEntity.java <==

package eu.dnetlib.dhp.schema.oaf;

import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

public abstract class OafEntity extends Oaf implements Serializable {

	private String id;

	private List<String> originalId;

	private List<StructuredProperty> pid;

	private String dateofcollection;

	private String dateoftransformation;

	private List<ExtraInfo> extraInfo;

	private OAIProvenance oaiprovenance;

	/**
	 * The Measures.
	 */
	private List<Measure> measures;

	/**
	 * The Context.
	 */
	private List<Context> context;

	/**
	 * Gets context.
	 *
	 * @return the context
	 */
	public List<Context> getContext() {
		return context;
	}

	/**
	 * Sets context.
	 *
	 * @param context the context
	 */
	public void setContext(List<Context> context) {
		this.context = context;
	}

	/**
	 * Gets measures.
	 *
	 * @return the measures
	 */
	public List<Measure> getMeasures() {
		return measures;
	}

	/**
	 * Sets measures.
	 *
	 * @param measures the measures
	 */
	public void setMeasures(List<Measure> measures) {
		this.measures = measures;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public List<String> getOriginalId() {
		return originalId;
	}

	public void setOriginalId(List<String> originalId) {
		this.originalId = originalId;
	}

	public List<StructuredProperty> getPid() {
		return pid;
	}

	public void setPid(List<StructuredProperty> pid) {
		this.pid = pid;
	}

	public String getDateofcollection() {
		return dateofcollection;
	}

	public void setDateofcollection(String dateofcollection) {
		this.dateofcollection = dateofcollection;
	}

	public String getDateoftransformation() {
		return dateoftransformation;
	}

	public void setDateoftransformation(String dateoftransformation) {
		this.dateoftransformation = dateoftransformation;
	}

	public List<ExtraInfo> getExtraInfo() {
		return extraInfo;
	}

	public void setExtraInfo(List<ExtraInfo> extraInfo) {
		this.extraInfo = extraInfo;
	}

	public OAIProvenance getOaiprovenance() {
		return oaiprovenance;
	}

	public void setOaiprovenance(OAIProvenance oaiprovenance) {
		this.oaiprovenance = oaiprovenance;
	}

	public void mergeFrom(OafEntity e) {
		super.mergeFrom(e);

		originalId = mergeLists(originalId, e.getOriginalId());

		pid = mergeLists(pid, e.getPid());

		if (e.getDateofcollection() != null && compareTrust(this, e) < 0)
			dateofcollection = e.getDateofcollection();

		if (e.getDateoftransformation() != null && compareTrust(this, e) < 0)
			dateoftransformation = e.getDateoftransformation();

		extraInfo = mergeLists(extraInfo, e.getExtraInfo());

		if (e.getOaiprovenance() != null && compareTrust(this, e) < 0)
			oaiprovenance = e.getOaiprovenance();

		measures = mergeLists(measures, e.getMeasures());

		context = mergeLists(context, e.getContext());
	}

	@SafeVarargs
	protected final <T> List<T> mergeLists(final List<T>... lists) {

		return Arrays
			.stream(lists)
			.filter(Objects::nonNull)
			.flatMap(List::stream)
			.filter(Objects::nonNull)
			.distinct()
			.collect(Collectors.toList());
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (o == null || getClass() != o.getClass())
			return false;
		if (!super.equals(o))
			return false;
		OafEntity oafEntity = (OafEntity) o;
		return Objects.equals(id, oafEntity.id);
	}

	@Override
	public int hashCode() {
		return Objects.hash(super.hashCode(), id);
	}
}

==> dhp-schemas-11.0.1-20250606.235028-2-sources.jar: eu/dnetlib/dhp/schema/oaf/OafEntity.java <==

package eu.dnetlib.dhp.schema.oaf;

import java.io.Serializable;
import java.util.*;

public abstract class OafEntity extends Oaf implements Serializable {

	private static final long serialVersionUID = -7793594664115821897L;

	private String id;

	/**
	 * MergedIds contains the list of the OpenAIRE IDs of the records merged into this one.
	 */
	private List<String> mergedIds;

	private List<String> originalId;

	private List<StructuredProperty> pid;

	private String dateofcollection;

	private String dateoftransformation;

	private List<ExtraInfo> extraInfo;

	private OAIProvenance oaiprovenance;

	/**
	 * The Measures.
	 */
	private List<Measure> measures;

	/**
	 * The Context.
	 */
	private List<Context> context;

	/**
	 * Gets context.
	 *
	 * @return the context
	 */
	public List<Context> getContext() {
		return context;
	}

	/**
	 * Sets context.
	 *
	 * @param context the context
	 */
	public void setContext(List<Context> context) {
		this.context = context;
	}

	/**
	 * Gets measures.
	 *
	 * @return the measures
	 */
	public List<Measure> getMeasures() {
		return measures;
	}

	/**
	 * Sets measures.
	 *
	 * @param measures the measures
	 */
	public void setMeasures(List<Measure> measures) {
		this.measures = measures;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public List<String> getOriginalId() {
		return originalId;
	}

	public List<String> getMergedIds() {
		return mergedIds;
	}

	public void setMergedIds(List<String> mergedIds) {
		this.mergedIds = mergedIds;
	}

	public void setOriginalId(List<String> originalId) {
		this.originalId = originalId;
	}

	public List<StructuredProperty> getPid() {
		return pid;
	}

	public void setPid(List<StructuredProperty> pid) {
		this.pid = pid;
	}

	public String getDateofcollection() {
		return dateofcollection;
	}

	public void setDateofcollection(String dateofcollection) {
		this.dateofcollection = dateofcollection;
	}

	public String getDateoftransformation() {
		return dateoftransformation;
	}

	public void setDateoftransformation(String dateoftransformation) {
		this.dateoftransformation = dateoftransformation;
	}

	public List<ExtraInfo> getExtraInfo() {
		return extraInfo;
	}

	public void setExtraInfo(List<ExtraInfo> extraInfo) {
		this.extraInfo = extraInfo;
	}

	public OAIProvenance getOaiprovenance() {
		return oaiprovenance;
	}

	public void setOaiprovenance(OAIProvenance oaiprovenance) {
		this.oaiprovenance = oaiprovenance;
	}

	@Override
	public int hashCode() {
		return Objects.hash(getId());
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (!(o instanceof OafEntity))
			return false;
		OafEntity oafEntity = (OafEntity) o;
		return Objects.equals(getId(), oafEntity.getId());
	}

}
